<?php

require_once("$STPHPLIB_DIR/stphpobject.php");
require_once("$STPHPLIB_DIR/stphplocale.php");

/**
* The class that represents an application
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPApplication extends STPHPObject
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPApplication
	* @param string $name
	*/
        function STPHPApplication($name)
        {
                STPHPObject::STPHPObject($name);

                ini_set('session.use_trans_sid','1');
                
                $this->sess_id = session_id();
                if(empty($this->sess_id))
                {
                        if(array_key_exists('PHPSESSID', $_GET))
			{
				$this->sess_id = $_GET['PHPSESSID'];
			}
			else
			{
				$this->sess_id = '';
			}
                }
                if(empty($this->sess_id))
                {
                        if(array_key_exists('PHPSESSID', $_POST))
			{
				$this->sess_id = $_POST['PHPSESSID'];
			}
			else
			{
				$this->sess_id = '';
			}
                }
                if(!empty($this->sess_id))
                {
                        session_id($this->sess_id);
                }
                session_start();
                $this->sess_id=session_id();

                if(empty($this->language))
                {
                        if(array_key_exists('STPHPLANGUAGE', $_GET))
			{
				$this->language = $_GET['STPHPLANGUAGE'];
			}
			else
			{
				$this->language = '';
			}
                }

                if(empty($this->language))
                {
                        if(array_key_exists('STPHPLANGUAGE', $_POST))
			{
				$this->language = $_POST['STPHPLANGUAGE'];
			}
			else
			{
				$this->language = '';
			}
                }

                if(empty($this->language))
                {
                        if(array_key_exists('STPHPLANGUAGE', $_SESSION))
			{
				$this->language = $_SESSION['STPHPLANGUAGE'];
			}
			else
			{
				$this->language = '';
			}
                }

                if(empty($this->language))
                {
                        $this->language = 'en';
                }
                $_SESSION['STPHPLANGUAGE'] = $this->language;

                if(empty($this->theme))
                {
                        if(array_key_exists('STPHPTHEME', $_GET))
			{
				$this->theme = $_GET['STPHPTHEME'];
			}
			else
			{
				$this->theme = '';
			}
                }

                if(empty($this->theme))
                {
                        if(array_key_exists('STPHPTHEME', $_POST))
			{
				$this->theme = $_POST['STPHPTHEME'];
			}
			else
			{
				$this->theme = '';
			}
                }

                if(empty($this->theme))
                {
                        if(array_key_exists('STPHPTHEME', $_SESSION))
			{
				$this->theme = $_SESSION['STPHPTHEME'];
			}
			else
			{
				$this->theme = '';
			}
                }

                if(empty($this->theme))
                {
                        $this->theme = 'default';
                }
                $_SESSION['STPHPTHEME'] = $this->theme;

		$this->title='';
		$this->author='';
		$this->copyright='';
		$this->version='';
		$this->wndMain='';
		$this->locale=0;
                $this->localizationActive = FALSE;
                $this->localeBasePath = '';
                $this->localeDefaultLanguage = '';
                $this->localeKeyLanguage = 'en';
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
		unset($this->title);
		unset($this->author);
		unset($this->copyright);
		unset($this->version);
		unset($this->language);
		
		$this->wndMain->dtor();
		unset($this->wndMain);
		
		unset($this->theme);
		unset($this->sess_id);
		
		if($this->locale)
		{
			$this->locale->dtor();
			unset($this->locale);
		}
		
		unset($this->localizationActive);
		unset($this->localeBasePath);
		unset($this->localeDefaultLanguage);
		unset($this->localeKeyLanguage);
                STPHPObject::dtor();
        }

        /**
	* Activate the localization support
	*
	* @access public
	*/
        function activateLocalization()
        {
                $this->localizationActive = TRUE;
        }

        /**
	* Deactivate the localization support
	*
	* @access public
	*/
        function deactivateLocalization()
        {
                $this->localizationActive = FALSE;
        }

        /**
	* Returns if the localization support is active
	*
	* @access public
	* @return bool
	*/
        function localizationIsActive()
        {
                return $this->localizationActive;
        }

        /**
	* Sets the base path for the localization files
	*
	* @access public
	* @param string $localeBasePath The base path
	*/
        function setLocaleBasePath($localeBasePath)
        {
                $this->localeBasePath = $localeBasePath;
        }

        /**
	* Sets the default language for the application
	*
	* @access public
	* @param string $localeDefaultLanguage The default language
	*/
        function setLocaleDefaultLanguage($localeDefaultLanguage)
        {
                $this->localeDefaultLanguage = $localeDefaultLanguage;
        }

        /**
	* Return a translated string
	*
	* @access public
	* @param string $text The text to translate
	* @return string The translated value
	*/
        function getLocaleText($text)
        {
                if($this->localizationIsActive())
                {
                        return $this->locale->getText($text);
                }
                else
                {
                        return $text;
                }
        }

        /**
	* Sets a variable in the session
	*
	* @access public
	* @param string $variable The variable name to set
	* @param string $value The variable value to set
	*/
        function setSessionVariable($variable, $value)
        {
                $_SESSION[$variable] = $value;
        }

        /**
	* Sets a variable in the session
	*
	* @access public
	* @param string $variable The variable name to set
	* @param string $value The variable value to set
	*/
        function getSessionVariable($variable)
        {
                return $_SESSION[$variable];
        }

        /**
	* Starts the application
	*
	* @access public
	* @param bool $compress TRUE if the output must be compressed (new line and tab characters removed)
	*/
        function init($compress=TRUE)
        {
                if(empty($this->localeDefaultLanguage))
                {
                        $this->localizationActive = FALSE;
                }

                if($this->localeDefaultLanguage == $this->localeKeyLanguage)
                {
                        $this->localizationActive = FALSE;
                }

                if($this->localizationActive)
                {
                        $this->locale = new STPHPLocale('locale');
                        $this->locale->setBasePath($this->localeBasePath);
                        $this->locale->setDefaultLanguage($this->localeDefaultLanguage);
                        $this->locale->loadKeys();
                        $this->locale->loadValues();
                }

                if(!empty($this->wndMain))
                {
                        $this->wndMain->init();
                }

                $retValue  = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">';
                $retValue .= '<HTML>';
                $retValue .= '<HEAD>';
                $retValue .= '<META http-equiv="Content-Type" content="text/html; charset=iso-8859-1">';
                if(!empty($this->author))
                {
                        $retValue .= '<META NAME=author CONTENT="' . $this->author . '">';
                }

                if(!empty($this->version))
                {
                        $retValue .= '<META NAME=version CONTENT="' . $this->version . '">';
                }

                if(!empty($this->copyright))
                {
                        $retValue .= '<META NAME=copyright CONTENT="' . $this->getCopyright() . '">';
                }
                
                $retValue .= '<META NAME=generator CONTENT="STPHPLib - http://stphplib.sourceforge.net">';

                if(!empty($this->wndMain))
                {
                        while (list ($key, $val) = each($this->wndMain->metaRows))
                        {
                                $retValue .= $val;
                        }
                }

                $retValue .= '<TITLE>' . $this->title . '</TITLE>';

                $codeFiles = array();
                $cssFiles = array();

                if(!empty($this->wndMain))
                {
                        $codeFiles=array_unique($this->wndMain->getCodeFiles());
                        while (list ($key, $val) = each ($codeFiles))
                        {
                                $retValue .= '<SCRIPT TYPE="text/javascript" SRC="' . $val . '"></SCRIPT>';
                        }

                        $cssFiles=array_unique($this->wndMain->getCssFiles());
                        while (list ($key, $val) = each ($cssFiles))
                        {
                                $retValue .= '<LINK REL=StyleSheet TYPE="text/css" HREF="' . $val . '">';
                        }

                }

                $retValue .= '</HEAD>';
                if(!empty($this->wndMain))
                {
                        $content = $this->wndMain->Write();
                        if($compress)
                        {
                                $content=str_replace("\n", '', $content);
                                $content=str_replace("\t", '', $content);
                        }
                        $retValue .= $content;
                }
                $retValue .= '</HTML>';

                echo $retValue;
        }

        /**
	* Sets the title of the application
	*
	* @access public
	* @param string $value The title
	*/
        function setTitle($value)
        {
                $this->title=$value;
        }

        /**
	* Gets the title of the application
	*
	* @access public
	* @return string The title
	*/
        function getTitle()
        {
                return $this->title;
        }

        /**
	* Sets the version of the application
	*
	* @access public
	* @param string $value The version
	*/
        function setVersion($value)
        {
                $this->version=$value;
        }

        /**
	* Gets the version of the application
	*
	* @access public
	* @return string The version
	*/
        function getVersion()
        {
                return $this->version;
        }

        /**
	* Sets the author of the application
	*
	* @access public
	* @param string $value The author
	*/
        function setAuthor($value)
        {
                $this->author=$value;
        }

        /**
	* Gets the author of the application
	*
	* @access public
	* @return string The author
	*/
        function getAuthor()
        {
                return $this->author;
        }

        /**
	* Sets the copyright of the application
	*
	* @access public
	* @param string $value The copyright
	*/
        function setCopyright($value)
        {
                $this->copyright=$value;
        }

        /**
	* Gets the copyright of the application
	*
	* @access public
	* @return string The copyright
	*/
        function getCopyright()
        {
                return "Copyright by " . $this->copyright;
        }

        /**
	* Sets the main window of the application
	*
	* @access public
	* @param STPHPWindow &$window The pointer to the main window
	*/
        function setWndMain(&$window)
        {
                $this->wndMain =& $window;
        }

        /**
	* Sets the language of the application
	*
	* @access public
	* @param string $value The language
	*/
        function setLanguage($value)
        {
                $this->language=strtoupper($value);
                $HTTP_SESSION_VARS['STPHPLANG'] = $this->language;
        }

        /**
	* Gets the language of the application
	*
	* @access public
	* @return string The language
	*/
        function getLanguage()
        {
                return $this->language;
        }

        /**
	* Sets the theme of the application
	*
	* @access public
	* @param string $value The theme
	*/
        function setTheme($value)
        {
                $this->theme=$value;
                $HTTP_SESSION_VARS['STPHPTHEME'] = $this->theme;
        }

        /**
	* Gets the theme of the application
	*
	* @access public
	* @return string The theme
	*/
        function getTheme()
        {
                return $this->theme;
        }

        /**
	* Sets the language of the keys localization files
	*
	* @access public
	* @param string $value The theme
	*/
        function setLocaleKeyLanguage($localeKeyLanguage)
        {
                $this->localeKeyLanguage=$localeKeyLanguage;
        }

        /**
	* Gets the language of the keys localization file
	*
	* @access public
	* @return string The key language
	*/
        function getLocaleKeyLanguage()
        {
                return $this->localeKeyLanguage;
        }

        /**
	* The title of the application
	*
	* @access private
	* @var string
	*/
        var $title;
	
        /**
	* The author of the application
	*
	* @access private
	* @var string
	*/
        var $author;
	
        /**
	* The copyright of the application
	*
	* @access private
	* @var string
	*/
        var $copyright;
	
        /**
	* The version of the application
	*
	* @access private
	* @var string
	*/
        var $version;
        
        /**
	* The language of the application
	*
	* @access private
	* @var string
	*/
	var $language;
	
        /**
	* The pointer to the main window
	*
	* @access private
	* @var STPHPWindow
	*/
        var $wndMain;
	
        /**
	* The theme of the application
	*
	* @access private
	* @var string
	*/
        var $theme;
	
        /**
	* The sessions id of the application
	*
	* @access private
	* @var string
	*/
        var $sess_id;
	
        /**
	* The localization object
	*
	* @access private
	* @var STPHPLocale
	*/
        var $locale;
	
        /**
	* The status of the localization support
	*
	* @access private
	* @var bool
	*/
        var $localizationActive;
	
        /**
	* The localization base path
	*
	* @access private
	* @var string
	*/
        var $localeBasePath;
	
        /**
	* The localization default language
	*
	* @access private
	* @var string
	*/
        var $localeDefaultLanguage;
	
        /**
	* The localization key language
	*
	* @access private
	* @var string
	*/
        var $localeKeyLanguage;
}

?>
