<?php

require_once("$STPHPLIB_DIR/stphpimagewithcaption.php");

/**
* A class that represents a sophisticated button
*
* It's possible to associate an image to a button and define a flat effect
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPBtnImage extends STPHPImageWithCaption
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPForm
	* @param string $name the name of the form used in NAME tag
	*/
        function STPHPBtnImage($name)
        {
                STPHPImageWithCaption::STPHPImageWithCaption($name);

                global $STJSLIB_DIR;
                $this->addCodeFile($STJSLIB_DIR . '/stjsbtnimage.js');
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - FLAT : defines if the button has the flat appearance
	* - IMAGE : defines the image for the button (used when FLAT option is not active)
	* - IMAGE_ON : defines the image when the cursor is over the button (used when FLAT option is active)
	* - IMAGE_OFF : defines the image when the cursor is not over the button (used when FLAT option is active)
	* - IMAGE_DOWN : defines the image when the button is pressed
	* - CAPTION : defines the caption of the button
	* - LINK : defines the link for the button
	* - LINK_TARGET : defines the target for the link
	* - ONCLICK : defines the onclick event hook
	* - CLASS : defines the CSS class
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
        function write()
        {
                $retValue  = "";
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		$this->control->appendAttributes($this->attributes);
		$this->caption->appendAttributes($this->attributes);

		$this->setAttribute('CAPTION_ALIGN', 'BOTTOM');
                $this->setAttribute('CAPTION_CLASS', $this->getAttribute('CLASS'));
                $this->setAttribute('CONTROL_CLASS', $this->getAttribute('CLASS'));

		if(strtoupper($this->getAttribute('FLAT')) == 'TRUE')
                {
                        $this->control->setAttribute('SRC', $this->getAttribute('IMAGE_OFF'));
                        $this->control->setAttribute('ONMOUSEOVER', 'javascript:STJSButton_SetImage(\'' . $this->name . '\', \'' . $this->getAttribute('IMAGE_ON') . '\')');
                        $this->control->setAttribute('ONMOUSEOUT', 'javascript:STJSButton_SetImage(\'' . $this->name . '\', \'' . $this->getAttribute('IMAGE_OFF') . '\')');
                }
                else
                {
                        $this->control->setAttribute('SRC', $this->getAttribute('IMAGE'));
                }

		if(!$this->attributeIsEmpty('IMAGE_DOWN'))
                {
                        $this->control->setAttribute('ONMOUSEDOWN','javascript:STJSButton_SetImage(\'' . $this->name . '\', \'' .  $this->getAttribute('IMAGE_DOWN') . '\')');
                        $this->control->setAttribute('ONMOUSEUP', 'javascript:STJSButton_SetImage(\'' . $this->name . '\', \'' . $this->getAttribute('IMAGE_ON') . '\')');
                }
			
		if($this->attributeIsEmpty('ALT'))
                {
			$this->control->setAttribute('ALT', $this->getAttribute('CAPTION'));
                }
	
                return STPHPImageWithCaption::write();
        }
	
	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXMLElement $configuration
	*/
        function setConfiguration(&$configuration)
        {
		STPHPComponent::setConfiguration($configuration);
        }	
}

?>
