<?php

require_once("$STPHPLIB_DIR/stphpcheckboxwithcaption.php");

/**
* A class that represents a group of checkbox
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPCheckGroup extends STPHPControlWithCaption
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPCheckGroup
	* @param string $name
	*/
        function STPHPCheckGroup($name)
        {
                STPHPControlWithCaption::STPHPControlWithCaption($name);
		$this->check = array();
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
		unset($this->numOfOptions);
		unset($this->check);
                STPHPControlWithCaption::dtor();
        }

        /**
	* Sets the number of checkboxes
	*
	* @access public
	* @param integer $options
	*/
        function setNumOfOptions($options)
        {
                $this->numOfOptions = $options;
        }

	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXMLElement $configuration
	*/
        function setConfiguration($configuration)
        {
                STPHPControlWithCaption::setConfiguration($configuration);
                $items = $this->configuration->getChildByName('items');
                $this->numOfOptions = $items->getNumOfChilds();
                $this->prepareCtrls();

                for($i=1; $i<=$this->numOfOptions; $i++)
                {
                        $item = $items->getChildByNameNum('item', $i);
                        $this->check[$i]->appendAttributes($items->attributes);
                        $this->check[$i]->setAttribute('CAPTION', $item->getAttribute('CAPTION'));
                        $this->check[$i]->setAttribute('CHECKED', $item->getAttribute('CHECKED'));
                        $this->check[$i]->setAttribute('DISABLED', $item->getAttribute('DISABLED'));
                        $this->check[$i]->setAttribute('VALUE', $item->data);
                }
        }

        /**
	* Prepare the controls
	*
	* @access private
	*/
	function prepareCtrls()
        {
                $this->tblControls = new STPHPTable('tbl_ctrls_' . $this->name);
                $this->tblControls->setNumOfRows($this->numOfOptions);
                $this->tblControls->setNumOfCols(1);
                $this->tblControls->prepare();
                
		for($i=1; $i<=$this->numOfOptions; $i++)
                {
                       $this->check[$i] = new STPHPCheckBoxWithCaption($i . '_' . $this->name);
                       $this->check[$i]->setFormParent($this->getFormParent()) ;
                       $this->tblControls->cells[$i][1]->setAttribute('ALIGN', 'LEFT');
                       $this->tblControls->cells[$i][1]->addComponent($this->check[$i]);
                }
        }

	/**
	* Prepare the objects and attributes before the designing of the object. Called automatically by write() method.
	*
	* @access private
	*/
        function prepareWrite()
        {
                STPHPControlWithCaption::prepareWrite();
                $this->ctlCell->addComponent($this->tblControls);
        }

        /**
	* The number of checkbox
	* @access private
	* @var integer
	*/
        var $numOfOptions;

        /**
	* The array of checkbox
	* @access private
	* @var STPHPCheckBoxWithCaption
	*/
	var $check;
}

?>
