<?php

require_once("$STPHPLIB_DIR/stphpobject.php");
require_once("$STPHPLIB_DIR/stphpspacer.php");

/**
* The base class for all components
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPComponent extends STPHPObject
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPComponent
	* @param string $name the name of the form used in NAME tag
	*/
        function STPHPComponent($name)
        {
                STPHPObject::STPHPObject($name);
                $this->attributes=array();
                $this->components=array();
		$this->formParent = '';
		$this->configuration = 0;
                $this->setAttribute('VISIBLE', 'TRUE');
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
		unset($this->attributes);

                if(isset($this->components))
                {
                        while (list ($key, $val) = each ($this->components))
                        {
                                $val->dtor();
                        }
                }
		unset($this->components);
		
		unset($this->formParent);
		
		if($this->configuration)
		{
			$this->configuration->dtor();
			unset($this->configuration);
		}
                
		STPHPObject::dtor();
        }

	/**
	* Inserts a component at the beginning of the components list
	*
	*
	* @access public
	* @param STPHPComponent &$component the component to add
	*/
        function insertComponent(&$component)
        {
                array_unshift($this->components, "0");
                $this->components[0] =& $component;
        }

	/**
	* Adds a component at the end of the components list
	*
	*
	* @access public
	* @param STPHPComponent &$component The component to add
	*/
        function addComponent(&$component)
        {
                $this->appendComponent($component);
        }

	/**
	* Appends a component at the end of the components list
	*
	*
	* @access public
	* @param STPHPComponent &$component The component to add
	*/
        function appendComponent(&$component)
        {
                $this->components[] =& $component;
        }

	/**
	* Adds vertical spaces
	*
	*
	* @access public
	* @param integer &$units The number of spaces
	*/
        function addVSpace($units)
        {
                $theSpacer = new STPHPSpacer("VSpace");
                $theSpacer->setSpaceType("VERTICAL");
                $theSpacer->setUnits($units);
                $this->addComponent($theSpacer);
        }

	/**
	* Adds a code file (Javascript)
	*
	*
	* @access public
	* @param string &$file The file to add
	*/
        function addCodeFile($file)
        {
                global $Wnd;
                $Wnd->addCodeFile($file);
        }

	/**
	* Adds a CSS file
	*
	*
	* @access public
	* @param string &$file The file to add
	*/
        function addCssFile($file)
        {
                global $Wnd;
                $Wnd->addCssFile($file);
        }

	/**
	* Sets an attribute
	*
	*
	* @access public
	* @param string $key The key of the attribute
	* @param string $val The value of the attribute
	*/
        function setAttribute($key, $val)
        {
                global $App;

		$key = strtoupper($key);
                if($key != 'NAME')
		{
			$val=str_replace('STPHPTHEME', $App->theme, $val);
		}
                $this->attributes[$key]=$val;
        }

	/**
	* Gets the value of an attribute
	*
	*
	* @access public
	* @param string $key The key of the attribute
	* @return string The value of the attribute
	*/
        function getAttribute($key)
        {
		if(array_key_exists($key, $this->attributes))
		{
			return($this->attributes[$key]);
		}
		else
		{
			return '';
		}
        }

	/**
	* Returns if attribute is empty
	*
	*
	* @access public
	* @param string $key The key of the attribute
	* @return bool TRUE if attribute is empty, FALSE otherwise
	*/
	function attributeIsEmpty($key)
	{
		$attribute = $this->getAttribute($key);
		return empty($attribute);
	}

	/**
	* Set an attribute to its translated value
	*
	*
	* @access public
	* @param string $key The key of the attribute
	*/
	function translateAttribute($key)
	{
		global $App;
		
		if(!empty($App))
		{
			$this->setAttribute($key, $App->getLocaleText($this->getAttribute($key)));
		}
	}

	/**
	* Translate an attribute to the current language
	*
	*
	* @access public
	* @param string $key The key of the attribute
	* @return string $key The translated value of the attribute
	*/
	function getTranslatedAttribute($key)
	{
		global $App;
		
		if(!empty($App))
		{
			return $App->getLocaleText($this->getAttribute($key));
		}
	}

	/**
	* Appends an array of attributes at the current values
	*
	*
	* @access public
	* @param array $attributes The attributes to append
	*/
        function appendAttributes($attributes)
        {
                 $this->attributes = array_merge($this->attributes, $attributes);
        }

	/**
	* Sets the form owner name of the component (used by JS functions)
	*
	*
	* @access public
	* @param string $attributes The name of form
	*/
        function setFormParent($form)
        {
                $this->formParent = $form;
        }

	/**
	* Returns the form owner name
	*
	*
	* @access public
	* @return string The name of form
	*/
        function getFormParent()
        {
                return $this->formParent;
        }

	/**
	* Designs the object at runtime
	*
	* @access private
	* @return string A null string
	*/
	function write()
	{
		return '';
	}

	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXmlElement $configuration
	*/
        function setConfiguration(&$configuration)
        {
                if(isset($configuration))
                {
                        $this->configuration =& $configuration;
                        $this->attributes = array_merge($this->attributes, $configuration->attributes);
                        $attributes=$this->configuration->getChildByName('attributes');
                }

                if(isset($attributes))
                {
                        $numOfAttributes = $attributes->getNumOfChilds();
                }
                else
                {
                        $numOfAttributes = 0;
                }

                for($i=1; $i<=$numOfAttributes; $i++)
                {
                        $attribute = $attributes->getChildByNum($i);
                        if(isset($attribute))
                        {
                                $this->setAttribute($attribute->name, $attribute->data);
                        }
                }
        }

        /**
	* The list of attributes
	*
	* @access private
	* @var array
	*/
        var $attributes;
	
        /**
	* The list of components
	*
	* @access private
	* @var array
	*/
        var $components;
	
        /**
	* The form owner name
	*
	* @access private
	* @var string
	*/
        var $formParent;
	
        /**
	* The pointer to configuration XML node
	*
	* @access private
	* @see STPHPXmlElement
	* @var STPHPXmlElement
	*/
        var $configuration;
}
?>
