<?php

require_once("$STPHPLIB_DIR/stphptable.php");
require_once("$STPHPLIB_DIR/stphplabel.php");

/**
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPControlWithCaption extends STPHPTable
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPTable
	* @param string $name
	*/
        function STPHPControlWithCaption($name)
        {
                STPHPTable::STPHPTable($name);
		$this->captionCell = 0;
		$this->ctlCell = 0;	
		$this->caption = new STPHPLabel('caption');
		$this->control = 0;
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
		unset($this->captionCell);
		unset($this->ctlCell);
		unset($this->caption);
		unset($this->control);
                STPHPTable::dtor();
        }

	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXMLElement $configuration
	*/
	function setConfiguration($configuration)
	{
		if(isset($configuration))
		{
			STPHPTable::setConfiguration($configuration);

			$control_conf = $this->configuration->getChildByName('control');
			if(isset($control_conf))
			{
				$this->control->setConfiguration($control_conf);
			}
			
			$caption_conf = $this->configuration->getChildByName('caption');
			if(isset($caption_conf))
			{
				$this->caption->setConfiguration($caption_conf);
			}
		}
        }

	/**
	* Prepare the objects and attributes before the designing of the object. Called automatically by write() method.
	*
	* @access private
	*/
        function prepareWrite()
        {
                switch(strtoupper($this->getAttribute('CAPTION_ALIGN')))
                {
                        case 'TOP':
                                $this->setNumOfRows(2);
                                $this->setNumOfCols(1);
                                $this->prepare();
                                $this->captionCell =& $this->cells[1][1];
                                $this->ctlCell =& $this->cells[2][1];
                        break;
                        case 'BOTTOM':
                                $this->setNumOfRows(2);
                                $this->setNumOfCols(1);
                                $this->prepare();
                                $this->captionCell =& $this->cells[2][1];
                                $this->ctlCell =& $this->cells[1][1];
                        break;
                        case 'LEFT':
                                $this->setNumOfRows(1);
                                $this->setNumOfCols(2);
                                $this->prepare();
                                $this->captionCell =& $this->cells[1][1];
                                $this->ctlCell =& $this->cells[1][2];
                        break;
                        case 'RIGHT':
                                $this->setNumOfRows(1);
                                $this->setNumOfCols(2);
                                $this->prepare();
                                $this->captionCell =& $this->cells[1][2];
                                $this->ctlCell =& $this->cells[1][1];
                        break;
                        default :
                                $this->setNumOfRows(1);
                                $this->setNumOfCols(2);
                                $this->prepare();
                                $this->captionCell =& $this->cells[1][1];
                                $this->ctlCell =& $this->cells[1][2];
                        break;
                }
                
		$this->caption->setAttribute('TEXT', $this->getAttribute('CAPTION'));
		$this->caption->setAttribute('CLASS', $this->getAttribute('CAPTION_CLASS'));		
		$this->captionCell->addComponent($this->caption);
		
                $this->captionCell->setAttribute('CLASS', $this->getAttribute('CAPTION_CLASS'));
                $this->ctlCell->setAttribute('CLASS', $this->getAttribute('CONTROL_CLASS'));
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - CAPTION : defines the caption
	* - CAPTION_ALIGN : defines the alignment of the caption (LEFT, RIGHT, TOP. BOTTOM)
	* - CAPTION_CLASS : defines the CSS class for the caption
	* - CONTROL_CLASS : defines the CSS class for the control
	* - CLASS : defines the CSS class
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
        function write()
        {
		$retValue = '';
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		$this->prepareWrite();

                if(!empty($this->control))
                {
                        $this->control->setAttribute('CLASS', $this->getAttribute('CONTROL_CLASS'));
                        $this->ctlCell->addComponent($this->control);
                }

                $retValue .= STPHPTable::write();

                return $retValue;
        }

        /**
	* The cell that contains the caption
	* @access private
	* @var STPHPTableCell
	*/
        var $captionCell;

        /**
	* The cell that contains the control
	* @access private
	* @var STPHPTableCell
	*/
	var $ctlCell;

        /**
	* The caption
	* @access private
	* @var STPHPLabel
	*/	
	var $caption;

        /**
	* The pointer to the control component
	* @access private
	* @var STPHPComponent
	*/
	var $control;	
}

?>
