<?php

require_once("$STPHPLIB_DIR/stphpcomponent.php");

/**
* A class that represents a form
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPForm extends STPHPComponent
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPForm
	* @param string $name the name of the form used in NAME tag
	*/
        function STPHPForm($name)
        {
                STPHPComponent::STPHPComponent($name);
                $this->variables = array();
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
                unset($this->variables);
		STPHPComponent::dtor();
        }

        /**
	* Adds a variable inside FORM tag
	*
	* @access public
	* @param string $variable the name of the variable
	* @param string $value the name of the variables value (optional)
	*/
        function addVariable($variable, $value='')
        {
                $this->variables[$variable] = $value;
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - NAME : defines the name of the form (if empty $name of the object is used)
	* - METHOD : defines the method for the form (GET/POST)
	* - ACTION : defines the action for the form
	* - TARGET : defines the target for the action
	* - ENCTYPE : defines the content type for the form
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
	function write()
        {
                $retValue  = "";
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		global $App;
                if(!empty($App))
		{
			$this->addVariable('PHPSESSID', $App->sess_id);
		}

                if($this->attributeIsEmpty('NAME'))
		{
			$this->setAttribute('NAME', $this->name);
		}

		$retValue .= '<FORM';

		if(!$this->attributeIsEmpty('NAME'))
                {
			$retValue .= ' NAME="' . $this->getAttribute('NAME') . '" ';
		}

		if(!$this->attributeIsEmpty('METHOD'))
                {
			$retValue .= ' METHOD="' . $this->getAttribute('METHOD') . '" ';
		}

		if(!$this->attributeIsEmpty('ACTION'))
                {
			$retValue .= ' ACTION="' . $this->getAttribute('ACTION') . '" ';
		}

		if(!$this->attributeIsEmpty('TARGET'))
                {
			$retValue .= ' TARGET="' . $this->getAttribute('TARGET') . '" ';
		}

		if(!$this->attributeIsEmpty('ENCTYPE'))
                {
			$retValue .= ' ENCTYPE="' . $this->getAttribute('ENCTYPE') . '" ';
		}

		$retValue .='>';
		reset($this->variables);
                while(list ($key, $val) = each ($this->variables))
                {
                        $retValue .= "<INPUT TYPE =\"HIDDEN\" NAME=\"$key\" VALUE=\"$val\">";
                }

                while (list ($key, $val) = each ($this->components))
                {
                        $retValue .= $val->Write();
                }

                $retValue .= '</FORM>';
                return $retValue;
        }

        /**
	* The list of variables of a form (input type=hidden elements)
	* @access private
	* @var array
	*/
	var $variables;
}

?>
