<?php

require_once("$STPHPLIB_DIR/stphpcomponent.php");

/**
* A class that represents an image
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPImage extends STPHPComponent
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPForm
	* @param string $name the name of the form used in NAME tag
	*/
        function STPHPImage($name)
        {
                STPHPComponent::STPHPComponent($name);
        }

        /**
	* Load an image from a db (using ADODB library)
	*
	* @access public
	* @param string $db_conf the configuration file for the db
	* @param string $table the table of the db
	* @param integer $record_id the record id
	* @param string $imgField the field of the db that contains the image
	* @param string $imgTypeField the field of the db that contains the type of the image
	* @param string $imgDesc the description of the image	
	*/
        function loadFromDb($db_conf, $table, $record_id, $imgField, $imgTypeField, $imgDesc)
        {
                global $STPHPLIBBASE_PATH;
                $this->setAttribute('SRC', "$STPHPLIBBASE_PATH/utils/stphpimage_show.php?db_conf=$db_conf&table=$table&record_id=$record_id&imgField=$imgField&imgTypeField=$imgTypeField");
                $this->setAttribute('ALT', $imgDesc);
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - SRC : the source for the image
	* - ALIGN : the alignment of the image
	* - ALT : the ALT text for the image
	* - LINK : defines the link for the label
	* - LINK_TARGET : defines the target for the link
	* - TITLE : defines the title for the link
	* - ONCLICK : defines the onclick event hook
	* - ONMOUSEOVER : defines the onmouseover event hook
	* - ONMOUSEOUT : defines the onmouseout event hook
	* - ONMOUSEDOWN : defines the onmousedown event hook
	* - ONMOUSEUP : defines the onmouseup event hook
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
        function write()
        {             
		$retValue = '';

		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		$this->translateAttribute('ALT');
		if($this->attributeIsEmpty('ALT'))
                {
                     $this->setAttribute('ALT', $this->name);
                }
               
		if(!$this->attributeIsEmpty('LINK'))
                {
                        $retValue .= '<A HREF="' . $this->getAttribute('LINK') . "\" ";
                        if(!$this->attributeIsEmpty('LINK_TARGET'))
                        {
                                $retValue .= 'TARGET= ' . $this->getAttribute('LINK_TARGET') . ' ';
                        }
                        if(!$this->attributeIsEmpty('ONCLICK'))
                        {
                                $retValue .= 'ONCLICK="' . $this->getAttribute('ONCLICK') . '" ';
                        }
                        if(!$this->attributeIsEmpty('TITLE'))
                        {
                                $retValue .= 'TITLE="' . $this->getTranslatedAttribute('TITLE') . '" ';
                        }
                        $retValue .= '>';
                }

		$retValue .= '<IMG NAME="' . $this->name . '"';
		$retValue .= ' BORDER=0 ';
		if(!$this->attributeIsEmpty('ALT'))
                {
			$retValue .= ' ALT="' . $this->getTranslatedAttribute('ALT') . '" ';
		}
		if(!$this->attributeIsEmpty('SRC'))
                {
			$retValue .= ' SRC="' . $this->getAttribute('SRC') . '" ';
		}
		if(!$this->attributeIsEmpty('ALIGN'))
                {
			$retValue .= ' ALIGN="' . $this->getAttribute('ALIGN') . '" ';
		}
                if(!$this->attributeIsEmpty('ONMOUSEOVER'))
		{
                        $retValue .= 'ONMOUSEOVER="' . $this->getAttribute('ONMOUSEOVER') . '" ';
                }
                if(!$this->attributeIsEmpty('ONMOUSEOUT'))
		{
                        $retValue .= 'ONMOUSEOUT="' . $this->getAttribute('ONMOUSEOUT') . '" ';
                }
                if(!$this->attributeIsEmpty('ONMOUSEDOWN'))
		{
                        $retValue .= 'ONMOUSEDOWN="' . $this->getAttribute('ONMOUSEDOWN') . '" ';
                }
                if(!$this->attributeIsEmpty('ONMOUSEUP'))
		{
                        $retValue .= 'ONMOUSEUP="' . $this->getAttribute('ONMOUSEUP') . '" ';
                }
		$retValue .= '>';

                if(!$this->attributeIsEmpty('LINK'))
                {
                        $retValue .= '</A>';
                }
                return $retValue;
        }
}

?>
