<?php

require_once("$STPHPLIB_DIR/stphpcomponent.php");

/**
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPListbox extends STPHPComponent
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPEdit
	* @param string $name
	*/
        function STPHPListbox($name)
        {
                STPHPComponent::STPHPComponent($name);
		$this->elements = array();
        }

         /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
       function dtor()
        {
                unset($this->elements);
                STPHPComponent::dtor();
        }

        /**
	* Add an element at the listbox
	*
	* @access public
	* @param string $key the key of the element
	* @param string $value the value of the element
	* @param bool $selected the element is selected or not
	*/
        function addElement($key, $value, $selected=FALSE)
        {
                if($selected=='TRUE')
                {
                        $selected=TRUE;
                }

                $i=sizeof($this->elements);
                $this->elements[$i][0]=$key;
                $this->elements[$i][1]=$value;
                $this->elements[$i][2]=$selected;
        }

        /**
	* Load the elements from a db
	*
	* @access public
	* @param string &$db the db instance
	* @param string $key_col the column that containes the keys
	* @param string $val_col the column that containes the value
	* @param string $sql the sql that extracts the elements
	*/
        function loadFromDb(&$db, $key_col, $val_col, $sql)
        {
                $recordSet =& $db->Execute($sql);
                if($recordSet)
                {
                        while(!$recordSet->EOF)
                        {
                                $key = $recordSet->fields[$key_col];
                                $val = $recordSet->fields[$val_col];
                                $this->addElement($key, $val);
                                $recordSet->MoveNext();
                        }
                        $recordSet->Close();
                }
        }

        /**
	* Select an element by its key
	*
	* @access public
	* @param string $key the key of the element
	*/
        function selectElementByKey($key)
        {
		$numOfElements = sizeof($this->elements);
                for($i=0; $i<$numOfElements; $i++)
                {
                        $this->elements[$i][2]=FALSE;
                        if($this->elements[$i][0]==$key)
                        {
                                $this->elements[$i][2]=TRUE;
                        }
                }
        }

        /**
	* Select an element by its value
	*
	* @access public
	* @param string $value the value of the element
	*/
        function selectElementByValue($value)
        {
                $numOfElements = sizeof($this->elements);
                for($i=0; $i<$numOfElements; $i++)
                {
                        $this->elements[$i][2]=FALSE;
                        if($this->elements[$i][1]==$value)
                        {
                                $this->elements[$i][2]=TRUE;
                        }
                }
        }

        /**
	* Clears the list of elements
	*
	* @access public
	*/
        function clearElements()
        {
                unset($this->elements);
		$this->elements = array();
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - NAME : defines the name of the form (if empty $name of the object is used)
	* - READONLY : if 'TRUE' the control is readonly
	* - DISABLED : if 'TRUE' the control is disabled
	* - MULTIPLE: if 'TRUE' the multi selection is enabled
	* - SIZE: the number of rows showed
	* - ONCHANGE : defines the onchange event hook	
	* - CLASS : defines the CSS class
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
        function write()
        {
		global $App;
	
                $retValue  = "";
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}


                if($this->attributeIsEmpty('NAME'))
		{
			$this->setAttribute('NAME', $this->name);
		}

		$retValue .= '<SELECT';

		if(!$this->attributeIsEmpty('NAME'))
                {
			$retValue .= ' NAME="' . $this->getAttribute('NAME') . '" ';
		}

		if($this->getAttribute('READONLY') == 'TRUE')
                {
			$retValue .= ' READONLY ';
		}

		if($this->getAttribute('DISABLED') == 'TRUE')
                {
			$retValue .= ' DISABLED ';
		}

		if($this->getAttribute('MULTIPLE') == 'TRUE')
                {
			$retValue .= ' MULTIPLE ';
		}

		if(!$this->attributeIsEmpty('SIZE'))
                {
			$retValue .= ' SIZE=' . $this->getAttribute('SIZE') . ' ';
		}

		if(!$this->attributeIsEmpty('ONCHANGE'))
                {
			$retValue .= ' ONCHANGE="' . $this->getAttribute('ONCHANGE') . '" ';
		}

		if(!$this->attributeIsEmpty('CLASS'))
                {
			$retValue .= ' CLASS="' . $this->getAttribute('CLASS') . '" ';
		}

		$retValue .'>';
	
                $numOfElements=sizeof($this->elements);
                for($i=0; $i<$numOfElements; $i++)
                {
                        $key=$this->elements[$i][0];
                        $value=$App->getLocaleText($this->elements[$i][1]);
                        $selected=$this->elements[$i][2];
                        if($selected)
                        {
                                $str_selected="SELECTED";
                        }
                        else
                        {
                                $str_selected="";
                        }

                        $retValue .= "<OPTION VALUE=\"$key\" $str_selected>$value";
                }

                $retValue .= '</SELECT>';
                return $retValue;
        }

	function setConfiguration(&$configuration)
	{
		if(isset($configuration))
		{
			STPHPComponent::setConfiguration($configuration);
			
			$items = $this->configuration->getChildByName('items');

                        if(isset($items))
                        {
                                $numOfItems = $items->getNumOfChilds();

                                for($i=1; $i<=$numOfItems; $i++)
                                {
                                        $item = $items->getChildByNameNum('item', $i);
                                        $this->addElement($item->data, $item->getAttribute('CAPTION'), $item->getAttribute('SELECTED'));
                                }
                        }
                }
	}

        /**
	* The list of elements of the listbox
	* @access private
	* @var array
	*/
        var $elements;
}

?>
