<?php

require_once("$STPHPLIB_DIR/stphpobject.php");
require_once("$STPHPLIB_DIR/stphpxmldoc.php");

/**
* The class that implements the localization of strings
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPLocale extends STPHPObject
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPLocale
	* @param string $name
	*/
        function STPHPLocale($name)
        {
                STPHPObject::STPHPObject($name);

                $this->basePath='';
                $this->defaultDomain='';
                $this->defaultLanguage='';

                $this->keys = array();
                $this->dkeys = array();
                $this->values = array();
                $this->dvalues = array();
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
                unset($this->basePath);
                unset($this->defaultDomain);
                unset($this->defaultLanguage);
                unset($this->keys);
                unset($this->dkeys);
                unset($this->values);
                unset($this->dvalues);
                STPHPObject::dtor();
        }

        /**
	* Sets the base path for the localization files
	*
	* @access public
	* @param string $localeBasePath The base path
	*/
        function setBasePath($basePath)
        {
                $this->basePath = $basePath;
        }

        /**
	* Gets the base path for the localization files
	*
	* @access public
	* @return string
	*/
        function getBasePath()
        {
                return $this->basePath;
        }

        /**
	* Sets the default domain
	*
	* @access public
	* @param string $defaultDomain
	*/
        function setDefaultDomain($defaultDomain)
        {
                $this->defaultDomain = $defaultDomain;
        }

        /**
	* Gets the default language
	*
	* @access public
	* @return string
	*/
        function getDefaultDomain()
        {
                return $this->defaultDomain;
        }
        
        /**
	* Gets the default language
	*
	* @access public
	* @return string
	*/
        function getDefaultLanguage()
        {
                return $this->defaultLanguage;
        }

        /**
	* Sets the default language
	*
	* @access public
	* @param string $defaultLanguage
	*/
        function setDefaultLanguage($defaultLanguage)
        {
                $this->defaultLanguage = $defaultLanguage;
        }

        /**
	* Gets a translated text (using the default domain and default language)
	*
	* @access public
	* @param string $value The value to translate
	* @return string
	*/
        function getText($value)
        {
                if(array_key_exists($value, $this->keys))
		{
			$key_id = $this->keys[$value];
		}
		else
		{
			$key_id = -1;
		}
                
		if(array_key_exists($key_id, $this->values[$this->defaultLanguage]))
		{
			$value_translated = $this->values[$this->defaultLanguage][$key_id];
		}
		else
		{
			$value_translated = '';
		}
                
		if(empty($value_translated))
                {
                        $value_translated = $value;
                }
                return $value_translated;
        }

        /**
	* Gets a translated text for the specified language (using the default domain)
	*
	* @access public
	* @param string $value The value to translate
	* @param string $language The language to use
	* @return string
	*/
        function lgetText($value, $language='')
        {
                if(empty($language))
                {
                        $language = $this->defaultLanguage;
                }

                $key_id = $this->keys[$value];
                $value_translated = $this->values[$language][$key_id];
                if(empty($value_translated))
                {
                        $value_translated = $value;
                }
                return $value_translated;
        }

        /**
	* Gets a translated text for the specified domain (using the default language)
	*
	* @access public
	* @param string $value The value to translate
	* @param string $domain The domain to use
	* @return string
	*/
        function dgetText($value, $domain='')
        {
                if(empty($domain))
                {
                        $domain = $this->defaultDomain;
                }

                $key_id = $this->dkeys[$domain][$value];
                $value_translated = $this->dvalues[$domain][$this->defaultLanguage][$key_id];
                if(empty($value_translated))
                {
                        $value_translated = $value;
                }
                return $value_translated;
        }

        /**
	* Gets a translated text for the specified domain and language
	*
	* @access public
	* @param string $value The value to translate
	* @param string $domain The domain to use
	* @param string $language The language to use
	* @return string
	*/
        function dlgetText($value, $domain='', $language='')
        {
                if(empty($domain))
                {
                        $domain = $this->defaultDomain;
                }

                if(empty($language))
                {
                        $language = $this->defaultLanguage;
                }

                $key_id = $this->dkeys[$domain][$value];
                $value_translated = $this->dvalues[$domain][$language][$key_id];
                if(empty($value_translated))
                {
                        $value_translated = $value;
                }
                return $value_translated;
        }

        /**
	* Loads the keys file
	*
	* @access public
	* @param string $fileKeys The keys file
	*/
        function loadKeys($fileKeys = '')
        {
                if(empty($fileKeys))
                {
                        $fileKeys = $this->basePath . '/keys.xml';
                }
                if(file_exists($fileKeys))
                {
                        $xmlDoc = new STPHPXmlDoc('xmlDoc');
                        $xmlDoc->readFromfile($fileKeys);

                        $nOfDomains = $xmlDoc->root->getNumOfChildsByName('domain');
                        for($i=1; $i<=$nOfDomains; $i++)
                        {
                             $xmlDomain = $xmlDoc->root->getChildByNameNum('domain', $i);
                             $domainName = $xmlDomain->getAttribute('name');
                             $xmlKeys = $xmlDomain->getChildByName('keys');
                             $nOfKeys = $xmlKeys->getNumOfChildsByName('key');
                             for($i=1; $i<=$nOfKeys; $i++)
                             {
                                $xmlKey = $xmlKeys->getChildByNum($i);
                                $key_id = $xmlKey->getAttribute('id');
                                $key_value = $xmlKey->getData();
                                $this->dkeys[$domainName][$key_value] = $key_id;
                                unset($xmlKey);
                             }
                             unset($xmlDomain);
                             unset($xmlKeys);
                        }

                        $xmlKeys = $xmlDoc->root->getChildByName('keys');
                        $nOfKeys = $xmlKeys->getNumOfChildsByName('key');
                        for($i=1; $i<=$nOfKeys; $i++)
                        {
                                $xmlKey = $xmlKeys->getChildByNum($i);
                                $key_id = $xmlKey->getAttribute('id');
                                $key_value = $xmlKey->getData();
                                $this->keys[$key_value] = $key_id;
                                unset($xmlKey);
                        }
                        unset($xmlKeys);

                        unset($xmlDoc);
                }
        }

        /**
	* Loads the values file
	*
	* @access public
	* @param string $language The languages values to load
	* @param string $fileValues The values file to load
	*/
        function loadValues($language='', $fileValues='')
        {
                if(empty($language))
                {
                        $language = $this->defaultLanguage;
                }

                if(empty($fileValues))
                {
                        $fileValues = $this->basePath . '/' . $language . '.xml';
                }

                $xmlDoc = new STPHPXmlDoc('xmlDoc');
                $xmlDoc->readFromfile($fileValues);

                $xmlLanguage =  $xmlDoc->root->getChildByName('language');
                if(empty($language))
                {
                        $language = $xmlLanguage->getData();
                }
                unset($xmlLanguage);

                $nOfDomains = $xmlDoc->root->getNumOfChildsByName('domain');
                for($i=1; $i<=$nOfDomains; $i++)
                {
                        $xmlDomain = $xmlDoc->root->getChildByNameNum('domain', $i);
                        $domainName = $xmlDomain->getAttribute('name');
                        $xmlValues = $xmlDomain->getChildByName('values');
                        $nOfValues = $xmlValues->getNumOfChildsByName('value');
                        for($i=1; $i<=$nOfValues; $i++)
                        {
                                $xmlValue = $xmlValues->getChildByNum($i);
                                $key_id = $xmlValue->getAttribute('key_id');
                                $value = $xmlValue->getData();
                                $this->dvalues[$domainName][$language][$key_id] = $value;
                                unset($xmlValue);
                        }
                        unset($xmlDomain);
                        unset($xmlValues);
                }

                $xmlValues = $xmlDoc->root->getChildByName('values');
                if (isset($xmlValues))
                {
                        $nOfValues = $xmlValues->getNumOfChildsByName('value');
                }
                else
                {
                        $nOfValues = 0;
                }
                for($i=1; $i<=$nOfValues; $i++)
                {
                        $xmlValue = $xmlValues->getChildByNum($i);
                        $key_id = $xmlValue->getAttribute('key_id');
                        $value = $xmlValue->getData();
                        $this->values[$language][$key_id] = $value;
                        unset($xmlValue);
                }
                unset($xmlValues);

                unset($xmlDoc);
        }

        /**
	* The base path for the locale files
	*
	* @access private
	* @var string
	*/
        var $basePath;
	
        /**
	* The default domain
	*
	* @access private
	* @var string
	*/        
	var $defaultDomain;
	
        /**
	* The default language
	*
	* @access private
	* @var string
	*/        
        var $defaultLanguage;

        /**
	* The array of keys
	*
	* @access private
	* @var array
	*/        
        var $keys;
	
        /**
	* The array of domains keys
	*
	* @access private
	* @var array
	*/        
        var $dkeys;
	
        /**
	* The array of values
	*
	* @access private
	* @var array
	*/        
        var $values;
	
        /**
	* The array of domains values
	*
	* @access private
	* @var array
	*/        
        var $dvalues;
}
?>
