<?php

/**
* A base class for every component
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPObject
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPObject
	* @param string $name
	*/
        function STPHPObject($name)
        {
                $this->name = $name;

                if(STPHP_DEBUG_ACTIVE)
                {
                        $errorMsg .= "constructing object ... \n";
                        $this->errorLog($errorMsg);
                }
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
                if(STPHP_DEBUG_ACTIVE)
                {
                        $errorMsg .= "destructing object ... \n";
                        $this->errorLog($errorMsg);
                }
                unset($this->name);
        }

        /**
	* Print an error to the log system
	*
	* @access public
	* @param string $message the error string
	*/
        function errorLog($message)
        {
                $errorMsg  = "STPHPLib : " . get_class($this) . "-" . $this->name . " : ";
                $errorMsg .= "$message \n";
                error_log($errorMsg, STPHP_DEBUG_TYPE, STPHP_DEBUG_DESTINATION);
        }

        /**
	* Returns the name of the object
	*
	* @access public
	* @return string
	*/
        function getName()
        {
                return $this->name;
        }

        /**
	* The name of the object
	* @access private
	* @var string
	*/
        var $name;
}

/**
* Determines if a object if of the specified type
*
* @access public
* @param Object $object the pointer to the object
* @param string $class the class of the object
*/
if(!function_exists('is_a'))
{
        function is_a(&$object, $class)
        {
                $retValue = is_subclass_of($object, $class);
                $retValue = $retValue || (strtolower($class) == strtolower(get_class($object)));
                return $retValue;
        }
}

?>
