<?php

require_once("$STPHPLIB_DIR/stphpcomponent.php");
require_once("$STPHPLIB_DIR/stphptablerow.php");

/**
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPTable extends STPHPComponent
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPTable
	* @param string $name
	*/
        function STPHPTable($name)
        {
                STPHPComponent::STPHPComponent($name);
 
                $this->numOfRows = 0;
                $this->numOfCols = 0;
                $this->rows = array();
                $this->cells = array();
                
                $this->setAttribute('BORDER', 0);
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
                unset($this->numOfRows);
                unset($this->numOfCols);
                unset($this->rows);
                unset($this->cells);
		STPHPComponent::dtor();
        }

	/**
	* Inserts a STPHPTableRow at the beginning of the components list
	*
	*
	* @access public
	* @param STPHPTableRow &$component the component to add
	*/
        function insertComponent(&$component)
        {
                if(is_a($component, "STPHPTableRow"))
                {
                        STPHPComponent::insertComponent($component);
                }
        }

	/**
	* Adds a STPHPTableCell at the end of the components list
	*
	*
	* @access public
	* @param STPHPTableRow &$component The component to add
	*/
        function addComponent(&$component)
        {
                $this->appendComponent($component);
        }

	/**
	* Appends a STPHPTableRow at the end of the components list
	*
	*
	* @access public
	* @param STPHPTableRow &$component The component to add
	*/
        function appendComponent(&$component)
        {
                if(is_a($component,"STPHPTableRow"))
                {
                        STPHPComponent::appendComponent($component);
                }
        }

	/**
	* Inserts a component directly to a cell
	*
	*
	* @access public
	* @param integer $row the rows number
	* @param integer $col the cols number
	* @param STPHPComponent &$component the component to insert
	*/
        function insertComponentToCell($row, $col, &$component)
        {
                if
                (
                        ($row>=1) && ($row<=sizeof($this->rows)) &&
                        ($col>=1) && ($col<=$this->numOfCols)
                )
                {
                        $this->cells[$row][$col]->insertComponent($component);
                }
        }

	/**
	* Appends a component directly to a cell
	*
	*
	* @access public
	* @param integer $row the rows number
	* @param integer $col the cols number
	* @param STPHPComponent &$component the component to append
	*/
        function appendComponentToCell($row, $col, &$component)
        {
                if
                (
                        ($row>=1) && ($row<=sizeof($this->rows)) &&
                        ($col>=1) && ($col<=$this->numOfCols)
                )
                {
                        $this->cells[$row][$col]->appendComponent($component);
                }
        }

	/**
	* Adds a component directly to a cell
	*
	*
	* @access public
	* @param integer $row the rows number
	* @param integer $col the cols number
	* @param STPHPComponent &$component the component to add
	*/
        function addComponentToCell($row, $col, &$component)
        {
                $this->appendComponentToCell($row, $col, $component);
        }

	/**
	* Sets the number of rows
	*
	*
	* @access public
	* @param integer $rows the rows number
	*/
        function setNumOfRows($rows)
        {
                $this->numOfRows=$rows;
        }

	/**
	* Sets the number of cols
	*
	*
	* @access public
	* @param integer $cols the cols number
	*/
        function setNumOfCols($cols)
        {
                $this->numOfCols=$cols;
        }

	/**
	* Prepare the table creating rows anc cells
	*
	*
	* @access public
	*/
        function prepare()
        {
                unset($this->rows);
                unset($this->cells);

                $this->rows=array();
                $this->cells=array();

                for($i=1; $i<=$this->numOfRows; $i++)
                {
                        $this->rows[$i] = new STPHPTableRow('tRow_' . $i . '_' . $this->name);
                        for($j=1; $j<=$this->numOfCols; $j++)
                        {
                                $this->cells[$i][$j] = new STPHPTableCell('tCell_' . $i . '_' . $j . $this->name);
                                $this->rows[$i]->addComponent($this->cells[$i][$j]);
                        }
                        $this->addComponent($this->rows[$i]);
                }
        }

	/**
	* Adds a new row to the table
	*
	*
	* @access public
	*/
        function addRow()
        {
                $i = sizeof($this->rows) + 1;
                $this->rows[$i] = new STPHPTableRow('tRow_' . $i . '_' . $this->name);
                for($j=1; $j<=$this->numOfCols; $j++)
                {
                        $this->cells[$i][$j] = new STPHPTableCell('tCell_' . $i . '_' . $j . '_' . $this->name);
                        $this->rows[$i]->addComponent($this->cells[$i][$j]);
                }
                $this->addComponent($this->rows[$i]);
                return $i;
        }

	/**
	* Adds vertical spaces to the specified cell
	*
	*
	* @access public
	* @param integer $row the rows number
	* @param integer $col the cols number
	* @param integer $units the spaces number
	*/
        function addVSpaceToCell($row, $col, $units)
        {
                if(($row<=sizeof($this->rows)) && ($col<=sizeof($this->cells[$row])))
                {
                        $this->cells[$row][$col]->addVSpace($units);
                }
        }

	/**
	* Adds text to the specified cell
	*
	*
	* @access public
	* @param integer $row the rows number
	* @param integer $col the cols number
	* @param string $text the text to add
	*/
        function addTextToCell($row, $col, $text)
        {
		$this->cells[$row][$col]->setAttribute('TEXT', $text);
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - BORDER : defines the border size of the table (default 0)
	* - CELLSPACING : defines the spacing of the cells (default 0)
	* - CELLPADING : defines the padding of the cells (default 0)
	* - ALIGN : defines the alignment
	* - WIDTH : defines the width
	* - CLASS : defines the CSS class
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
	function write()
	{
		$retValue = '';
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		$retValue .= '<TABLE';

		if(!$this->attributeIsEmpty('BORDER'))
                {
			$retValue .= ' BORDER=' . $this->getAttribute('BORDER') . ' ';
		}
		else
		{
			$retValue .= ' BORDER=0 ';
		}

		if(!$this->attributeIsEmpty('CELLSPACING'))
                {
			$retValue .= ' CELLSPACING=' . $this->getAttribute('CELLSPACING') . ' ';
		}
		else
		{
			$retValue .= ' CELLSPACING=0 ';
		}

		if(!$this->attributeIsEmpty('CELLPADDING'))
                {
			$retValue .= ' CELLPADDING=' . $this->getAttribute('CELLPADDING') . ' ';
		}
		else
		{
			$retValue .= ' CELLPADDING=0 ';
		}

		if(!$this->attributeIsEmpty('ALIGN'))
                {
			$retValue .= ' ALIGN=' . $this->getAttribute('ALIGN') . ' ';
		}

		if(!$this->attributeIsEmpty('WIDTH'))
                {
			$retValue .= ' WIDTH="' . $this->getAttribute('WIDTH') . '" ';
		}

		if(!$this->attributeIsEmpty('CLASS'))
                {
			$retValue .= ' CLASS="' . $this->getAttribute('CLASS') . '" ';
		}
		
		$retValue .= '>';
		
                if(isset($this->components))
                {
                        while (list ($key, $val) = each ($this->components))
                        {
                                $retValue .= $val->write();
                        }
                }		
		
		$retValue .= '</TABLE>';
		return $retValue;	
	}

        /**
	* The number of rows of the table
	* @access private
	* @var integer
	*/
        var $numOfRows;

        /**
	* The number of cols of the table
	* @access private
	* @var integer
	*/
	var $numOfCols;

	/**
	* The rows of the table (an array of STPHPTableRow objects)
	* @access private
	* @var array
	*/
        var $rows;

	/**
	* The cells of the table (an array of STPHPTableCell objects)
	* @access private
	* @var array
	*/
        var $cells;
}

?>
