<?php

require_once("$STPHPLIB_DIR/stphppanel.php");
require_once("$STPHPLIB_DIR/stphptabtitle.php");

/**
* A class that represents panel with a title and tabs
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPTabPanel extends STPHPPanel
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPPanel
	* @param string $name
	*/
        function STPHPTabPanel($name)
        {
                STPHPPanel::STPHPPanel($name);
                $this->tabs = array();

                global $App;

                if(array_key_exists($name, $_GET))
		{
			$this->tabSelected = $_GET[$name];
		}
                
		if(empty($this->tabSelected))
                {
			if(array_key_exists($name, $_POST))
			{
				$this->tabSelected = $_POST[$name];
			}
                }
                if(empty($this->tabSelected))
                {
                        $this->tabSelected = $App->getSessionVariable($name);
                }
                if(empty($this->tabSelected))
                {
                        $this->tabSelected = 1;
                }
                $App->setSessionVariable($name, $this->tabSelected);
        }

	/**
	* Add a tab
	*
	* @access public
	* @param STPHPTabTitle $item The tab to add
	*/
        function addTab(&$item)
        {
                $nOfTabs = sizeof($this->tabs);
                $this->tabs[$nOfTabs+1] =& $item;
        }

	/**
	* Add a component to a tab
	*
	* @access public
	* @param index $tab The tab index
	* @param STPHPComponent &$component The component to add
	*/
        function addComponentToTab($tab, &$component)
        {
                if(!isset($this->dummyCells[$tab]))
                {
                        $this->dummyCells[$tab] = new STPHPTableCell('dummyCell_' . $tab);
                }
                $this->dummyCells[$tab]->addComponent($component);
        }

	/**
	* Return the index of the current selected tab
	*
	* @access public
	* @return integer
	*/
        function getTabSelected()
        {
                return $this->tabSelected;
        }

	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXMLElement $configuration
	*/
        function setConfiguration($configuration)
        {
                STPHPPanel::setConfiguration($configuration);
                $tabs = $this->configuration->getChildByName('tabs');
                
                if(isset($tabs))
                {
                        $numOfTabs = $tabs->getNumOfChilds();

                        if(!isset($this->tab))
                        {
                                $this->tab = array();
                        }
                        for($i=1; $i<=$numOfTabs; $i++)
                        {
                                $tab = $tabs->getChildByNameNum('tab', $i);
                                $name = $tab->attributes['NAME'];
                                $this->tab[$i] = new STPHPTabTitle('$name');
                                $this->tab[$i]->appendAttributes($tabs->attributes);
                                $this->tab[$i]->setConfiguration($tab);
                                $this->addTab($this->tab[$i]);
                        }
                }
        }

	/**
	* Prepare the objects and attributes before the designing of the object. Called automatically by write() method.
	*
	* @access private
	*/
        function prepareWrite()
        {
                global $App;

                STPHPPanel::prepareWrite();

                $tabs_position = strtoupper($this->getAttribute('TABS_POSITION'));
                $tabs_align = strtoupper($this->getAttribute('TABS_ALIGN'));

                switch($tabs_position)
                {
                                case 'TOP':
                                $row = 1;
                                switch($tabs_align)
                                {
                                        case 'LEFT':
                                        $col=2;
                                        break;
                                        case 'CENTER':
                                        $col=3;
                                        break;
                                        case 'RIGHT':
                                        $col=4;
                                        break;
                                        default:
                                        $tabs_align = 'LEFT';
                                        $col=2;
                                        break;
                                }
                                break;
                                case 'BOTTOM':
                                        $row = 5;
                                        switch($tabs_align)
                                        {
                                                case 'LEFT':
                                                $col=2;
                                                break;
                                                case 'CENTER':
                                                $col=3;
                                                break;
                                                case 'RIGHT':
                                                $col=4;
                                                break;
                                                default:
                                                $tabs_align = 'LEFT';
                                                $col=2;
                                                break;
                                        }
                                        break;
                                case 'LEFT':
                                        $col = 1;
                                        switch($tabs_align)
                                        {
                                                case 'TOP':
                                                $row=2;
                                                break;
                                                case 'MIDDLE':
                                                $row=3;
                                                break;
                                                case 'BOTTOM':
                                                $row=4;
                                                break;
                                                default:
                                                $tabs_align = 'TOP';
                                                $row=2;
                                                break;
                                        }
                                        break;
                                case 'RIGHT':
                                        switch($tabs_align)
                                        {
                                                case 'TOP':
                                                $col=3;
                                                $row=2;
                                                break;
                                                case 'MIDDLE':
                                                $col=2;
                                                $row=3;
                                                break;
                                                case 'BOTTOM':
                                                $col=2;
                                                $row=4;
                                                break;
                                                default:
                                                $tabs_align = 'TOP';
                                                $col=3;
                                                $row=2;
                                                break;
                                        }
                                        break;
                                default :
                                        $tabs_position = 'TOP';
                                        $tabs_align = 'LEFT';
                                        $row = 1;
                                        $col = 2;
                                        break;
                }

                $ntabs = sizeof($this->tabs);
                $this->tblContainer = new STPHPTable('container');
                $this->tblContainer->setAttribute('CELLPADDING', 0);
                $this->tblContainer->setAttribute('CELLSPACING', 0);
                if($tabs_position=='TOP' || $tabs_position=='BOTTOM')
                {
                        $this->tblContainer->setNumOfRows(1);
                        $this->tblContainer->setNumOfCols($ntabs);
                }
                else if($tabs_position=='LEFT' || $tabs_position=='RIGHT')
                {
                        $this->tblContainer->setNumOfRows($ntabs);
                        $this->tblContainer->setNumOfCols(1);
                }
                $this->tblContainer->prepare();

                for($i=1; $i<=$ntabs; $i++)
                {
                        $this->tabs[$i]->setAttribute('STATUS', 'DESELECTED');
                        $this->tabs[$i]->setAttribute('LINK', $this->tabs[$i]->getAttribute('LINK') . '?PHPSESSID=' . $App->sess_id . '&' . $this->name . '=' . ($i));
                        if($tabs_position=='TOP' || $tabs_position=='BOTTOM')
                        {
                                $this->tblContainer->addComponentToCell(1, $i, $this->tabs[$i]);
                        }
                        else if($tabs_position=='LEFT' || $tabs_position=='RIGHT')
                        {
                                $this->tblContainer->addComponentToCell($i, 1, $this->tabs[$i]);
                        }
                }
                if($tabs_align=='LEFT' || $tabs_align=='CENTER')
                {
                        $this->cells[$row][$col]->appendComponent($this->tblContainer);
                }
                else if($tabs_align=='RIGHT')
                {
                        $this->cells[$row][$col]->insertComponent($this->tblContainer);
                }
                if($tabs_align=='TOP' || $tabs_align=='MIDDLE')
                {
                        $this->cells[$row][$col]->appendComponent($this->tblContainer);
                }
                else if($tabs_align=='BOTTOM')
                {
                        $this->cells[$row][$col]->insertComponent($this->tblContainer);
                }

                if($ntabs>0)
                {
                        $this->tabs[$this->tabSelected]->setAttribute('STATUS', 'SELECTED');
                        $this->cells[2][2]->components =& $this->dummyCells[$this->tabSelected]->components;
                }
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
	function write()
	{
		$this->prepareWrite();
		return STPHPTable::write();
	}

        /**
	* The list of tabs
	* @access private
	* @var array of STPHPTabTitle
	*/
        var $tabs;
	
        /**
	* The selected tab
	* @access private
	* @var integer
	*/
        var $tabSelected;
	
        /**
	* Cells used to contain components
	* @access private
	* @var array of STPHPTableCell
	*/
        var $dummyCells;
}

?>
