<?php

require_once("$STPHPLIB_DIR/stphptable.php");
require_once("$STPHPLIB_DIR/stphpbtnimage.php");
require_once("$STPHPLIB_DIR/stphpeditwithcaption.php");
require_once("$STPHPLIB_DIR/stphplabel.php");
require_once("$STPHPLIB_DIR/stphphr.php");

/**
* A class that represents a toolbar. Can contain every type of component.
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPToolbar extends STPHPTable
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPForm
	* @param string $name the name of the form used in NAME tag
	*/
	function STPHPToolbar($name)
	{
		STPHPTable::STPHPTable($name);
		$this->buttons = array();
		$this->setAttribute('ALIGNMENT','HORIZONTAL');
	}

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
	function dtor()
	{
		unset($this->buttons);
		STPHPTable::dtor();
	}

        /**
	* Adds a button to the toolbar
	*
	* @access public
	* @param STPHPComponent &$button
	*/
	function addButton(&$button)
	{
		$numOfButtons = sizeof($this->buttons);
		$this->buttons[$numOfButtons+1] =& $button;
	}

        /**
	* Gets the button index from its name
	*
	* @access public
	* @param string $name the name of the button
	* @return integer the index of the button
	*/
	function getNumOfButtonByName($name)
	{
		reset($this->buttons);
		$numOfButtons = sizeof($this->buttons);
		for($i=1; $i<=$numOfButtons; $i++)
		{
			if($this->buttons[$i]->getName() == $name)
			{
				return $i;
			}
		}
	}

	/**
	* Load the attributes from a STPHPXMLElement object
	*
	* @access public
	* @param STPHPXMLElement $configuration
	*/
	function setConfiguration($configuration)
	{
		if(isset($configuration))
		{
			STPHPControlWithCaption::setConfiguration($configuration);
			$items = $this->configuration->getChildByName('buttons');
			if(isset($items))
			{
				$numOfItems = $items->getNumOfChilds();
				for($i=1; $i<=$numOfItems; $i++)
				{
					$item = $items->getChildByNameNum('button', $i);
					$name = $item->getAttribute('NAME');
					$type = $item->attributes['TYPE'];
					eval("\$this->button[$i] = new $type('$name');");
					if(isset($this->button[$i]))
					{
						$this->button[$i]->appendAttributes($items->attributes);
						$this->button[$i]->setConfiguration($item);
						$this->addButton($this->button[$i]);
					}
				}
			}
		}
	}

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - ALIGNMENT : defines the alignment of the toolbar (HORIZONTAL|VERTICAL  -  HORIZONTAL is the default)
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
	function write()
	{
                $retValue  = "";
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}

		$numOfButtons = sizeof($this->buttons);

		if(strtoupper($this->attributes['ALIGNMENT'])=='HORIZONTAL')
		{
			$this->setNumOfRows(2);
			$this->setNumOfCols($numOfButtons);
		}
		else if(strtoupper($this->attributes['ALIGNMENT'])=='VERTICAL')
		{
			$this->setNumOfCols(1);
			$this->setNumOfRows($numOfButtons);
		}

		$this->prepare();

		$rowBtnIndex=0;

		for($i=1; $i<=$numOfButtons; $i++)
		{
			if(strtoupper($this->attributes['ALIGNMENT'])=='HORIZONTAL')
			{
				$rowBtnIndex=1;
				$colBtnIndex=$i;
			}
			else if(strtoupper($this->attributes['ALIGNMENT'])=='VERTICAL')
			{
				$rowBtnIndex=$rowBtnIndex+1;
				$colBtnIndex=1;
			}

			$this->cells[$rowBtnIndex][$colBtnIndex]->setAttribute('VALIGN', 'BOTTOM');
			$this->cells[$rowBtnIndex][$colBtnIndex]->setAttribute('ALIGN', 'CENTER');

			$this->cells[$rowBtnIndex][$colBtnIndex]->addComponent($this->buttons[$i]);

			$link_class = '';
			if(empty($this->buttons[$i]->attributes['CLASS']))
			{
				$this->buttons[$i]->setAttribute('CLASS', 'btnToolbar');
			}
		}

		return STPHPTable::write();
	}

        /**
	* The list of buttons
	* @access private
	* @var array
	*/
	var $buttons;
}

?>
