<?php

require_once("$STPHPLIB_DIR/stphpcomponent.php");

/**
* The class that represents a window
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPWindow extends STPHPComponent
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPWindow
	* @param string $name
	*/
        function STPHPWindow($name)
        {
                STPHPComponent::STPHPComponent($name);
                $this->codeFiles = array();
                $this->cssFiles = array();
                $this->metaRows = array();
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {		
                unset($this->codeFiles);
                unset($this->cssFiles);
                unset($this->metaRows);
                STPHPComponent::dtor();
        }

        /**
	* Add a code file
	*
	* @access public
	* @param string $codeFile The code file name to add
	*/
        function addCodeFile($codeFile)
        {
                $this->codeFiles[$codeFile]=$codeFile;
        }

        /**
	* Returns the array of codes files 
	*
	* @access public
	* @return array
	*/
        function getCodeFiles()
        {
                return $this->codeFiles;
        }

        /**
	* Add a CSS file
	*
	* @access public
	* @param string $cssFile The CSS file name to add
	*/
        function addCssFile($cssFile)
        {
                global $App;
                $this->cssFiles[$cssFile]=str_replace('STPHPTHEME', $App->theme, $cssFile);
        }

        /**
	* Returns the array of CSS files 
	*
	* @access public
	* @return array
	*/
        function getCssFiles()
        {
                return $this->cssFiles;
        }

        /**
	* Add a META tag
	*
	* @access public
	* @param string $metaRow The meta row to add
	*/
        function addMetaRow($metaRow)
        {
                $this->metaRows[] = $metaRow;
        }

	/**
	* Designs the object at runtime
	*
	* Available attributes :
	* - VISIBLE : defines if the component must be designed or not
	* - CLASS : defines the CSS class
	*
	* @access private
	* @return string the code that represents the object at runtime
	*/
	function write()
	{
		$retValue = '';
		if($this->getAttribute('VISIBLE') == 'FALSE')
		{
			return '';
		}
		
		$retValue .= '<BODY';
		
		if(!$this->attributeIsEmpty('CLASS'))
                {
			$retValue .= ' CLASS="' . $this->getAttribute('CLASS') . '" ';
		}

		$retValue .= '>';

                if(isset($this->components))
                {
                        while (list ($key, $val) = each ($this->components))
                        {
                                $retValue .= $val->write();
                        }
                }		

		$retValue .= '</BODY>';
		
		return $retValue;
	}
	
        /**
	* The list of code files (JavaScript code)
	*
	* @access private
	* @var array
	*/
        var $codeFiles;
	
        /**
	* The list of CSS files
	*
	* @access private
	* @var array
	*/	
        var $cssFiles;
	
        /**
	* The list of META tag
	*
	* @access private
	* @var array
	*/	
        var $metaRows;
}

?>
