<?php

require_once("$STPHPLIB_DIR/stphpobject.php");

/**
* The class that represents a XML node
*
* @version 0.8
* @author Roberto Gerola <roberto.gerola@speedtech.it>
* @package stphplib
*/
class STPHPXmlElement extends STPHPObject
{
        /**
	* Creates the object
	*
	* @access public
	* @return STPHPXmlElement
	* @param string $name
	*/
        function STPHPXmlElement($name)
        {
                STPHPObject::STPHPObject($name);
		$this->parent=0;
		$this->attributes=array();
		$this->data='';
		$this->childs=array();
        }

        /**
	* Destructor
	*
	* Destroys all the resources associated with the object
	*
	* @access public
	*/
        function dtor()
        {
		unset($this->parent);
                unset($this->attributes);
                unset($this->data);
		
                $numOfChilds = $this->getNumOfChilds();
                for($i=0; $i<$numOfChilds; $i++)
                {
                        $this->childs[$i]->dtor();
                }
                unset($this->childs);
                STPHPObject::dtor();
        }

        /**
	* Returns the number of childs of the node
	*
	* @return integer
	*/
        function getNumOfChilds()
        {
                return sizeof($this->childs);
        }

        /**
	* Returns the number of childs of the node with the specified name
	*
	* @param string $childName the name of the node
	* @return integer
	*/
        function getNumOfChildsByName($childName)
        {
                $count = 0;
                $numOfChilds = $this->getNumOfChilds();
                for($i=0; $i<$numOfChilds; $i++)
                {
                        $child =& $this->childs[$i];
                        if(strtoupper($child->name)==strtoupper($childName))
                        {
                                $count++;
                        }
                }
                return $count;
        }

        /**
	* Returns a child by its name
	*
	* @param string $childName the name of the node
	* @return STPHPXmlElement
	*/
        function getChildByName($childName)
        {
                $numOfChilds = $this->getNumOfChilds();
                for($i=0; $i<$numOfChilds; $i++)
                {
                        $child =& $this->childs[$i];
                        if(strtoupper($child->name)==strtoupper($childName))
                        {
                                return $child;
                        }
                }
        }

        /**
	* Returns a child by its name and index
	*
	* @param string $childName the name of the node
	* @param integer $num The index number
	* @return STPHPXmlElement
	*/
        function getChildByNameNum($childName, $num=0)
        {
                $count=0;

                $numOfChilds = $this->getNumOfChilds();
                for($i=0; $i<$numOfChilds; $i++)
                {
                        $child =& $this->childs[$i];
                        if(strtoupper($child->name)==strtoupper($childName))
                        {
                                $count++;
                        }
                        if($count==$num)
                        {
                                return $child;
                        }
                }
        }

        /**
	* Returns a child by its index
	*
	* @param integer $num The index number
	* @return STPHPXmlElement
	*/
        function getChildByNum($num)
        {
                $child =& $this->childs[$num-1];
                return $child;
        }
        
        /**
	* Returns the value of the specified attribute
	*
	* @param string $name The name of the attribute
	* @return string
	*/
        function getAttribute($name)
        {
                if(array_key_exists(strtoupper($name), $this->attributes))
		{
			return $this->attributes[strtoupper($name)];
		}
		else
		{
			return '';
		}
        }
        
        /**
	* Returns the value of the node
	*
	* @return string
	*/
        function getData()
        {
                return $this->data;
        }

        /**
	* The parent node
	*
	* @access private
	* @var STPHPXmlElement
	*/	
        var $parent;
	
        /**
	* The attributes of the node
	*
	* @access private
	* @var array
	*/	
        var $attributes;
	
        /**
	* The data value of the node
	*
	* @access private
	* @var string
	*/	
        var $data;
	
        /**
	* The childs of the node
	*
	* @access private
	* @var array
	*/	
        var $childs;
}
?>
